==> haskell-fast-logger-2.4.7-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fast-logger
version: 2.4.7
id: fast-logger-2.4.7-5q6cKzCUmhpFUH581aMKto
key: fast-logger-2.4.7-5q6cKzCUmhpFUH581aMKto
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/logger
synopsis: A fast logging system
description:
    A fast logging system
category: System
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.File
    System.Log.FastLogger.Date
hidden-modules: System.Log.FastLogger.IO
                System.Log.FastLogger.FileIO System.Log.FastLogger.IORef
                System.Log.FastLogger.LogStr System.Log.FastLogger.Logger
abi: fb0ce9f303f398f6e73e8cfec47731ec
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/fast-logger-2.4.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/fast-logger-2.4.7
data-dir: /usr/share/i386-linux-ghc-8.0.1/fast-logger-2.4.7
hs-libraries: HSfast-logger-2.4.7-5q6cKzCUmhpFUH581aMKto
depends:
    array-0.5.1.1 auto-update-0.1.4-GAesfFmqoZzBz6e09kRyzb base-4.9.0.0
    bytestring-0.10.8.1 directory-1.2.6.2
    easy-file-0.2.1-bAUkz2rC2kFhBbPjw2Of5 filepath-1.4.1.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ unix-2.7.2.0
    unix-time-0.3.7-HcxGsrnTmTlC98pyanzoMW
haddock-interfaces: /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html: /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fast-logger-2.4.10-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fast-logger
version: 2.4.10
id: fast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
key: fast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/logger
synopsis: A fast logging system
description:
    A fast logging system
category: System
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.File
    System.Log.FastLogger.Date
hidden-modules: System.Log.FastLogger.IO
                System.Log.FastLogger.FileIO System.Log.FastLogger.IORef
                System.Log.FastLogger.LogStr System.Log.FastLogger.Logger
abi: 3e74e1c16e2d267ae31e6bbf2c523466
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/fast-logger-2.4.10
library-dirs: /usr/lib/ghc-8.0.1/site-local/fast-logger-2.4.10
data-dir: /usr/share/i386-linux-ghc-8.0.1/fast-logger-2.4.10
hs-libraries: HSfast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
depends:
    array-0.5.1.1 auto-update-0.1.4-GAesfFmqoZzBz6e09kRyzb base-4.9.0.0
    bytestring-0.10.8.1 directory-1.2.6.2
    easy-file-0.2.1-bAUkz2rC2kFhBbPjw2Of5 filepath-1.4.1.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ unix-2.7.2.0
    unix-time-0.3.7-HcxGsrnTmTlC98pyanzoMW
haddock-interfaces: /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html: /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
